@@ -54,7 +54,7 @@ class _ThreadResult:
 
 class SSHClient(object):
     def __init__(self, ip="127.0.0.1", port=22, username="root", password="", connect_timeout=10,get_tty=False):
-        log.info(f"{self.__ip}:{self.__port} | init SSHClient, ip:{ip}, port:{port}, username:{username},password:{password},connect_timeout:{connect_timeout},get_tty:{get_tty}")
+        log.info(f"{ip}:{port} | init SSHClient, ip:{ip}, port:{port}, username:{username},password:{password},connect_timeout:{connect_timeout},get_tty:{get_tty}")
         self.__ip = ip
         self.__port = port
         self.__username = username
